===========  ====================================================
Info         NI SystemLink API Clients for Python
Author       National Instruments
===========  ====================================================

About
=====
The **nisystemlink-clients** package contains an API (Application Programming
Interface) for `SystemLink <https://ni.com/systemlink>`_ that uses HTTP to
interact with a SystemLink Server. The package is implemented in Python. NI
created and supports this package.

.. image:: https://badge.fury.io/py/nisystemlink-clients.svg
    :target: https://badge.fury.io/py/nisystemlink-clients

Requirements
============
**nisystemlink-clients** has the following requirements:

* A SystemLink Server installation or a
  `SystemLink Cloud <https://www.systemlinkcloud.com/>`_ account to connect to
* CPython 3.8+

.. _installation_section:

Installation
============
To install **nisystemlink-clients**, use one of the following methods:

1. `pip <https://pypi.python.org/pypi/pip>`_::

   $ python -m pip install nisystemlink-clients

2. **easy_install** from `setuptools <https://pypi.python.org/pypi/setuptools>`_::

   $ python -m easy_install nisystemlink-clients

.. _usage_section:

Usage
=====
Refer to the `documentation <https://python-docs.systemlink.io>`_
for detailed information on how to use **nisystemlink-clients**.

.. _support_section:

Support / Feedback
==================
The **nisystemlink-clients** package is supported by NI. For support for
**nisystemlink-clients**, open a request through the NI support portal at
`ni.com <https://www.ni.com>`_.

Bugs / Feature Requests
=======================
To report a bug or submit a feature request, please use the
`GitHub issues page <https://github.com/ni/nisystemlink-clients-python/issues>`_.

Documentation
=============
To view the documentation, visit the
`nisystemlink.clients Documentation Page <https://python-docs.systemlink.io>`_.

Changelog
=============
To view the changelog, visit the
`GitHub repository CHANGELOG <https://github.com/ni/nisystemlink-clients-python/blob/master/CHANGELOG.md>`_.

License
=======
**nisystemlink-clients** is licensed under an MIT-style license (see `LICENSE
<LICENSE>`_).  Other incorporated projects may be licensed under different
licenses. All licenses allow for non-commercial and commercial use.
